breed [students student]
breed [universities university]
globals [
  predict-score           ; the predict score of university (may be the min-score or max-rank)

  min-score-sd            ;
  min-score-bm            ;
  min-score-da            ;
  min-score-tm            ;
  min-score-cp            ;
  min-score               ;;

  max-rank                ;; the ranking of the students who has the lowest scores and was admitted to the universities

  max-rank-score-sd       ;
  max-rank-score-bm       ;
  max-rank-score-da       ;
  max-rank-score-tm       ;
  max-rank-score-cp       ;
  max-rank-score          ;; the score in this year according to the max-rank last year

  high-school
  num-univ                ;; number of universities
  univ
  u
  mean-utility
  average-mismatch-sd     ;; to measure the error
  average-mismatch-bm     ;; to measure the error
  average-mismatch-da     ;; to measure the error
  average-mismatch-tm     ;; to measure the error
  average-mismatch-cp     ;; to measure the error

  sd-mismatch-sd          ;; standard deviation of the mismatch
  sd-mismatch-bm          ;; standard deviation of the mismatch
  sd-mismatch-da          ;; standard deviation of the mismatch
  sd-mismatch-tm          ;; standard deviation of the mismatch
  sd-mismatch-cp          ;; standard deviation of the mismatch

  mean-quartile           ;; the average misplacement of each quartile
  mean-top10
  max-top10
  percent-top10
  x                       ;; to produce random number
  no-choices              ;; total number of choices
  score-mean              ;
  score-sd                ;
  three-letter-score-t1
  three-letter-score-t2
  mu
]

universities-own[
  priority-students-list   ;;
  potential-students
]
students-own [
  score                     ;; students'score
  preference-list           ;; student's preference
  choice                    ;; a list to store student's total choice (use n-value choices []
  choice-score              ;; choice score for "Taipei mechanism"
  ten-scale-score
  three-letter-score        ;; 3-letter score
  total-composite-score     ;;
  last-choice               ;; index for deferred acceptance
  next-choice               ;; index for deferred acceptance
  choice-1                  ;; a list of student's first choice under Chinese parallel
  choice-2                  ;; a list of student's second choice under Chinese parallel
  utility                   ;; utility the students have
  base-place                ;; where he could go
  actual-place              ;; where he goes actually
  misplacement-abs          ;; to measure the misplacement-abs (absolute distance of base-place and what he really get)
  misplacement              ;; to measure misplacement gain or loss
  rank
]

to setup
  clear-all
  ;random-seed 0
  set-default-shape students "person"
  set-default-shape universities "house"
  set num-univ 10
  set three-letter-score-t1 84
  set three-letter-score-t2 36
  set mu 3

  set min-score n-values num-univ [0]
  set min-score-sd min-score
  set min-score-bm min-score
  set min-score-da min-score
  set min-score-tm min-score
  set min-score-cp min-score

  set max-rank n-values num-univ [num-students]

  set mean-quartile n-values 4 [0]
  set predict-score n-values num-univ [random 100]    ; (list random 100 random 100 random 100 random 100 random 100 random 100 random 100 random 100 random 100 random 100)
  setup-schools                                       ;; setup ten universities and high-school
  setup-students

  if All_mechanism? [
    if write-mismatch [
      if file-exists? "mismatch.csv" and keep_files = FALSE and behaviorspace-run-number = 0 [file-delete "mismatch.csv"]
      if NOT file-exists? "mismatch.csv" [
        file-open "mismatch.csv"         ;; write the average-mismatch in the file mismatch
        file-print (word
          "run,"
          "ticks,"
          "scheme,"
          "alpha,"
          "capacity,"
          "order,"
          "choices,"
          "choices-2,"
          "sd,"
          "bm,"
          "da,"
          "tm,"
          "cp"
          )
        file-close
      ]
    ]
    if write-sd-mismatch [
      if file-exists? "sd_mismatch.csv" and keep_files = FALSE and behaviorspace-run-number = 0 [file-delete "sd_mismatch.csv"]
      if NOT file-exists? "sd_mismatch.csv"[
        file-open "sd_mismatch.csv"      ;; write the average-mismatch in the file mismatch
        file-print (word
          "run,"
          "ticks,"
          "scheme,"
          "alpha,"
          "capacity,"
          "order,"
          "choices,"
          "choices-2,"
          "sd,"
          "bm,"
          "da,"
          "tm,"
          "cp"
          )
        file-close
      ]
    ]
    if write-min-score [
      if file-exists? "min_score.csv" and keep_files = FALSE and behaviorspace-run-number = 0 [file-delete "min_score.csv"]
      if NOT file-exists? "min_score.csv" [
        file-open "min_score.csv"
        file-print (word
          "run,"
          "ticks,"
          "scheme,"
          "alpha,"
          "capacity,"
          "order,"
          "choices,"
          "choices-2,"
          "sd 1,sd 2,sd 3,sd 4,sd 5,sd 6,sd 7,sd 8,sd 9,sd 10,"
          "bm 1,bm 2,bm 3,bm 4,bm 5,bm 6,bm 7,bm 8,bm 9,bm 10,"
          "da 1,da 2,da 3,da 4,da 5,da 6,da 7,da 8,da 9,da 10,"
          "tm 1,tm 2,tm 3,tm 4,tm 5,tm 6,tm 7,tm 8,tm 9,tm 10,"
          "cp 1,cp 2,cp 3,cp 4,cp 5,cp 6,cp 7,cp 8,cp 9,cp 10,"
          )
        file-close
      ]
    ]
    if write-mean-quartile-score [
      if file-exists? "mean_quartile_score.csv" and keep_files = FALSE and behaviorspace-run-number = 0 [file-delete "mean_quartile_score.csv"]
      if NOT file-exists? "mean_quartile_score.csv" [
        file-open "mean_quartile_score.csv"
        file-print (word
          "run,"
          "ticks,"
          "scheme,"
          "alpha,"
          "capacity,"
          "order,"
          "choices,"
          "choices-2,"
          "sd 25%,sd 50%,sd 75%,sd 100%,"
          "bm 25%,bm 50%,bm 75%,bm 100%,"
          "da 25%,da 50%,da 75%,da 100%,"
          "tm 25%,tm 50%,tp 75%,tp 100%,"
          "cp 25%,cp 50%,cp 75%,cp 100%,"
          )
        file-close
      ]
    ]
    if write-mean-top10 [
      if file-exists? "mean_top10.csv" and keep_files = FALSE and behaviorspace-run-number = 0 [file-delete "mean_top10.csv"]
      if NOT file-exists? "mean_top10.csv" [
        file-open "mean_top10.csv"
        file-print (word
          "run,"
          "ticks,"
          "scheme,"
          "alpha,"
          "capacity,"
          "order,"
          "choices,"
          "choices-2,"
          "sd,"
          "bm,"
          "da,"
          "tm,"
          "cp"
          )
        file-close
      ]
    ]
    if write-max-top10 [
      if file-exists? "max_top10.csv" and keep_files = FALSE and behaviorspace-run-number = 0 [file-delete "max_top10.csv"]
      if NOT file-exists? "max_top10.csv" [
        file-open "max_top10.csv"
        file-print (word
          "run,"
          "ticks,"
          "scheme,"
          "alpha,"
          "capacity,"
          "order,"
          "choices,"
          "choices-2,"
          "sd,"
          "bm,"
          "da,"
          "tm,"
          "cp"
          )
        file-close
      ]
    ]
    if write-percent-top10 [
      if file-exists? "percent_top10.csv" and keep_files = FALSE and behaviorspace-run-number = 0 [file-delete "percent_top10.csv"]
      if NOT file-exists? "percent_top10.csv" [
        file-open "percent_top10.csv"
        file-print (word
          "run,"
          "ticks,"
          "scheme,"
          "alpha,"
          "capacity,"
          "order,"
          "choices,"
          "choices-2,"
          "sd,"
          "bm,"
          "da,"
          "tm,"
          "cp"
          )
        file-close
      ]
    ]
  ]

  reset-ticks
end

to setup-schools
  set univ n-values num-univ [?]
  let n 0
  let d (max-pxcor - min-pxcor) / num-univ
  repeat num-univ
   [
     set univ replace-item (n / d) univ  patches with [pycor > -10 and pxcor > (- (max-pxcor) + n) and pxcor < (- (max-pxcor - d) + n)]
     ask  patches with [pycor > -10 and pxcor > (- (max-pxcor) + n) and pxcor < (- (max-pxcor - d) + n)] [set pcolor blue ]
     ask patch (- (max-pxcor - d / 2) + n) -10 [set plabel-color white set plabel (n / d  + 1) ]
     ask patch (- (max-pxcor - d / 2) + n) -11 [set plabel-color red set plabel  item (n / d)  predict-score  ]
     ask one-of item (n / d) univ [sprout-universities 1 [set color white]]
     set n (n + d) ]
   set high-school patches with  [pycor < -11]
   ask high-school [set pcolor lime - 4]
end

to setup-students
  create-students num-students [
    set last-choice 0
    set next-choice 0
    setxy random-xcor (- 12 - random 5)
    set color magenta
    set size 1
              ;;  set choice n-values 10  [10 ]
  ]
end

to generate-preference
  set preference-list []
  let school-list n-values num-univ [? + 1]
  let j 1
  repeat num-univ [
    let z-value zipf (num-univ + 1 - j) alpha
    let y item (z-value - 1)  school-list
    set preference-list lput y preference-list
    set school-list remove-item (z-value - 1)  school-list
    set j (j + 1)
  ]
end

to generate-students-priority
  set priority-students-list []
  ;let students-list n-values num-students [? + 1]
  let school-id who + 1
  ifelse mechanism = "Taipei mechanism"
    [set priority-students-list sort-on [(- (score / 1001 + (ten-scale-score - 1) / 10 + three-letter-score  + (30 - floor (ifelse-value is-number? (position school-id choice) [position school-id choice / group-size][0]))))] students]
    [set priority-students-list sort-on [(- score)] students]
end

to go-to-high-school
  move-to one-of high-school
  set color magenta
  ;set actual-place 11
  set last-choice 0
  set next-choice 0               ;; index for deferred acceptance
  ;set base-place 11                ;; where he could go
  ;set actual-place 11             ;; where he goes actually
end

to go
  if ticks >= max-tick  [stop]
;;  set score-mean (random-normal population-mean population-standard-deviation)
;;  if score-mean > (population-mean + population-standard-deviation) [set score-mean (population-mean + population-standard-deviation)]
;;  if score-mean < (population-mean - population-standard-deviation) [set score-mean (population-mean - population-standard-deviation)]

  set score-mean (random-normal population-mean (population-standard-deviation / 3.0))

  set score-sd sqrt (random-gamma 30 0.5 * population-standard-deviation ^ 2  / 60)
  ask students [get-score]                     ;; get score
  ask students [generate-preference]           ;; generate random preference list according to the probability matrix P
  ;set max-rank-score [45.226066053306866 45.226066053306866 45.226066053306866 45.226066053306866 45.226066053306866 45.226066053306866 45.226066053306866 45.226066053306866 45.226066053306866 45.226066053306866]
  if ticks = 0 [
    get-max-rank-score
    set max-rank-score-sd max-rank-score
    set max-rank-score-bm max-rank-score
    set max-rank-score-da max-rank-score
    set max-rank-score-tm max-rank-score
    set max-rank-score-cp max-rank-score
  ]
  ;; ask students  [set base-place 11]

  ;ask student 10 [set score 50.65641505 set preference-list [1 3 2 5 6 4 7 8 9 10] set choice [1 3 2 5 6 4]]
  ;ask student 11 [set score 56.79255603 set preference-list [2 1 3 4 5 6 7 9 8 10] set choice [2 1 3 4 5 6]]
  ;ask student 12 [set score 67.49415357 set preference-list [4 1 2 3 5 6 7 8 9 10] set choice [4 1 2 3 5 6]]
  ;ask student 13 [set score 65.28547071 set preference-list [1 2 3 4 5 6 7 8 10 9] set choice [1 2 3 4 5 6]]
  ;ask student 14 [set score 58.99698166 set preference-list [1 2 4 5 6 3 7 8 9 10] set choice [1 2 4 5 6 3]]
  ;ask student 15 [set score 70.41955061 set preference-list [2 1 3 4 7 5 6 8 9 10] set choice [2 1 3 4 7 5]]
  ;ask student 16 [set score 58.72389879 set preference-list [1 2 3 4 5 7 6 9 8 10] set choice [1 2 3 4 5 7]]
  ;ask student 17 [set score 63.46864411 set preference-list [1 2 3 4 5 6 7 10 8 9] set choice [1 2 3 4 5 6]]
  ;ask student 18 [set score 45.22606605 set preference-list [1 2 3 6 4 5 7 9 8 10] set choice [1 2 3 6 4 5]]
  ;ask student 19 [set score 71.38564526 set preference-list [1 2 3 4 5 6 7 8 9 10] set choice [1 2 3 4 5 6]]
  ask students [get-three-latter-score]

  ask students [go-to-high-school]

  let mechanisms (list "Serial dictatorship" "Boston mechanism" "Deferred acceptance" "Taipei mechanism" "Chinese parallel mechanism")

  let mean-quartile-sd []
  let mean-quartile-bm []
  let mean-quartile-da []
  let mean-quartile-tm []
  let mean-quartile-cp []

  let mean-top10-sd 0
  let mean-top10-bm 0
  let mean-top10-da 0
  let mean-top10-tm 0
  let mean-top10-cp 0

  let max-top10-sd 0
  let max-top10-bm 0
  let max-top10-da 0
  let max-top10-tm 0
  let max-top10-cp 0

  let percent-top10-sd 0
  let percent-top10-bm 0
  let percent-top10-da 0
  let percent-top10-tm 0
  let percent-top10-cp 0

  ifelse All_mechanism? [
    foreach mechanisms [
      set mechanism ?
      set no-choices (no-choices-1 + no-choices-2)
      get-fair-place                              ;; to find out the base-place, i.e. the university that the student could go
      if ? = "Serial dictatorship" [
        set min-score min-score-sd
        set max-rank-score max-rank-score-sd
      ]
      if ? = "Boston mechanism" [
        set min-score min-score-bm
        set max-rank-score max-rank-score-bm
      ]
      if ? = "Deferred acceptance" [
        set min-score min-score-da
        set max-rank-score max-rank-score-da
      ]
      if ? = "Taipei mechanism" [
        set min-score min-score-tm
        set max-rank-score max-rank-score-tm
      ]
      if ? = "Chinese parallel mechanism" [
        set min-score min-score-cp
        set max-rank-score max-rank-score-cp
      ]
      ask students [go-to-high-school]
      ask students [set next-choice 0 set last-choice 0 choose]
      ask universities [generate-students-priority]
      enroll
      ask students [calculate-misplacement]
      update-min-score-and-rank
      get-max-rank-score
      update-label
      class-mismatch
      if ? = "Serial dictatorship" [
        set average-mismatch-sd mean [misplacement-abs] of students ;show  average-mismatch-sd
        set sd-mismatch-sd standard-deviation [misplacement-abs] of students
        set min-score-sd min-score
        set max-rank-score-sd max-rank-score
        set mean-quartile-sd mean-quartile
        set mean-top10-sd mean-top10
        set max-top10-sd max-top10
        set percent-top10-sd percent-top10                         ;; to report misplacement-abs
      ]
      if ? = "Boston mechanism" [
        set average-mismatch-bm mean [misplacement-abs] of students ;show average-mismatch-bm
        set sd-mismatch-bm standard-deviation [misplacement-abs] of students
        set min-score-bm min-score
        set max-rank-score-bm max-rank-score
        set mean-quartile-bm mean-quartile
        set mean-top10-bm mean-top10
        set max-top10-bm max-top10
        set percent-top10-bm percent-top10                         ;; to report misplacement-abs
      ]
      if ? = "Deferred acceptance" [
        set average-mismatch-da mean [misplacement-abs] of students ;show  average-mismatch-da
        set sd-mismatch-da standard-deviation [misplacement-abs] of students
        set min-score-da min-score
        set max-rank-score-da max-rank-score
        set mean-quartile-da mean-quartile
        set mean-top10-da mean-top10
        set max-top10-da max-top10
        set percent-top10-da percent-top10                         ;; to report misplacement-abs
      ]
      if ? = "Taipei mechanism" [
        set average-mismatch-tm mean [misplacement-abs] of students ;show  average-mismatch-tm
        set sd-mismatch-tm standard-deviation [misplacement-abs] of students
        set min-score-tm min-score
        set max-rank-score-tm max-rank-score
        set mean-quartile-tm mean-quartile
        set mean-top10-tm mean-top10
        set max-top10-tm max-top10
        set percent-top10-tm percent-top10                         ;; to report misplacement-abs
      ]
      if ? = "Chinese parallel mechanism" [
        set average-mismatch-cp mean [misplacement-abs] of students ;show  average-mismatch-cp
        set sd-mismatch-cp standard-deviation [misplacement-abs] of students
        set min-score-cp min-score
        set max-rank-score-cp max-rank-score
        set mean-quartile-cp mean-quartile
        set mean-top10-cp mean-top10
        set max-top10-cp max-top10
        set percent-top10-cp percent-top10                         ;; to report misplacement-abs
      ]

      ;set sd-mismatch standard-deviation [misplacement-abs] of students
      ;; set mean-utility mean [utility] of students with [color = yellow ]
    ]
    if write-mismatch [
      file-open "mismatch.csv"         ;; write the average-mismatch in the file mismatch
      file-print (word 
        behaviorspace-run-number
        " ," ticks
        " ," scheme
        " ," alpha
        " ," capacity
        " ," extra-in-order
        " ," no-choices
        " ," no-choices-2
        " ," average-mismatch-sd
        " ," average-mismatch-bm
        " ," average-mismatch-da
        " ," average-mismatch-tm
        " ," average-mismatch-cp
        )
      file-close
    ]
    if write-sd-mismatch [
      file-open "sd_mismatch.csv"      ;; write the average-mismatch in the file mismatch
      file-print (word 
        behaviorspace-run-number
        " ," ticks
        " ," scheme
        " ," alpha
        " ," capacity
        " ," extra-in-order
        " ," no-choices
        " ," no-choices-2
        " ," sd-mismatch-sd
        " ," sd-mismatch-bm
        " ," sd-mismatch-da
        " ," sd-mismatch-tm
        " ," sd-mismatch-cp
        )
      file-close
    ]
    if write-min-score [
      file-open "min_score.csv"
      file-print (word 
        behaviorspace-run-number
        " ," ticks
        " ," scheme
        " ," alpha
        " ," capacity
        " ," extra-in-order
        " ," no-choices
        " ," no-choices-2 " ,"
        cut-list min-score-sd
        cut-list min-score-bm
        cut-list min-score-da
        cut-list min-score-tm
        cut-list min-score-cp
        )
      file-close
    ]
    if write-mean-quartile-score [
      file-open "mean_quartile_score.csv"
      file-print (word 
        behaviorspace-run-number
        " ," ticks
        " ," scheme
        " ," alpha
        " ," capacity
        " ," extra-in-order
        " ," no-choices
        " ," no-choices-2 " ,"
        cut-list mean-quartile-sd
        cut-list mean-quartile-bm
        cut-list mean-quartile-da
        cut-list mean-quartile-tm
        cut-list mean-quartile-cp
        )
      file-close
    ]
    if write-mean-top10 [
      file-open "mean_top10.csv"
      file-print (word  
        behaviorspace-run-number
        " ," ticks
        " ," scheme
        " ," alpha
        " ," capacity
        " ," extra-in-order
        " ," no-choices
        " ," no-choices-2
        " ," mean-top10-sd
        " ," mean-top10-bm
        " ," mean-top10-da
        " ," mean-top10-tm
        " ," mean-top10-cp
        )
      file-close
    ]
    if write-max-top10 [
      file-open "max_top10.csv"
      file-print (word  
        behaviorspace-run-number
        " ," ticks
        " ," scheme
        " ," alpha
        " ," capacity
        " ," extra-in-order
        " ," no-choices
        " ," no-choices-2
        " ," max-top10-sd
        " ," max-top10-bm
        " ," max-top10-da
        " ," max-top10-tm
        " ," max-top10-cp
        )
      file-close
    ]
    if write-percent-top10 [
      file-open "percent_top10.csv"
      file-print (word  
        behaviorspace-run-number
        " ," ticks
        " ," scheme
        " ," alpha
        " ," capacity
        " ," extra-in-order
        " ," no-choices
        " ," no-choices-2
        " ," percent-top10-sd
        " ," percent-top10-bm
        " ," percent-top10-da
        " ," percent-top10-tm
        " ," percent-top10-cp
        )
      file-close
    ]
  ]
  [
    set no-choices (no-choices-1 + no-choices-2)
    get-fair-place                              ;; to find out the base-place, i.e. the university that the student could go
    ask students [go-to-high-school]
    if mechanism = "Serial dictatorship" [
      set min-score min-score-sd
      set max-rank-score max-rank-score-sd
    ]
    if mechanism = "Boston mechanism" [
      set min-score min-score-bm
      set max-rank-score max-rank-score-bm
    ]
    if mechanism = "Deferred acceptance" [
      set min-score min-score-da
      set max-rank-score max-rank-score-da
    ]
    if mechanism = "Taipei mechanism" [
      set min-score min-score-tm
      set max-rank-score max-rank-score-tm
    ]
    if mechanism = "Chinese parallel mechanism" [
      set min-score min-score-cp
      set max-rank-score max-rank-score-cp
    ]
    ask students [set next-choice 0 set last-choice 0 choose]
    ask universities [generate-students-priority]
    enroll
    ask students [calculate-misplacement]
    update-min-score-and-rank
    get-max-rank-score
    update-label
    class-mismatch
    if mechanism = "Serial dictatorship" [
      set average-mismatch-sd mean [misplacement-abs] of students ;show  average-mismatch-sd
      set sd-mismatch-sd standard-deviation [misplacement-abs] of students
      set min-score-sd min-score
      set max-rank-score-sd max-rank-score
      set mean-quartile-sd mean-quartile
      set mean-top10-sd mean-top10
      set max-top10-sd max-top10
      set percent-top10-sd percent-top10                         ;; to report misplacement-abs
    ]
    if mechanism = "Boston mechanism" [
      set average-mismatch-bm mean [misplacement-abs] of students ;show average-mismatch-bm
      set sd-mismatch-bm standard-deviation [misplacement-abs] of students
      set min-score-bm min-score
      set max-rank-score-bm max-rank-score
      set mean-quartile-bm mean-quartile
      set mean-top10-bm mean-top10
      set max-top10-bm max-top10
      set percent-top10-bm percent-top10                         ;; to report misplacement-abs
    ]
    if mechanism = "Deferred acceptance" [
      set average-mismatch-da mean [misplacement-abs] of students ;show  average-mismatch-da
      set sd-mismatch-da standard-deviation [misplacement-abs] of students
      set min-score-da min-score
      set max-rank-score-da max-rank-score
      set mean-quartile-da mean-quartile
      set mean-top10-da mean-top10
      set max-top10-da max-top10
      set percent-top10-da percent-top10                         ;; to report misplacement-abs
    ]
    if mechanism = "Taipei mechanism" [
      set average-mismatch-tm mean [misplacement-abs] of students ;show  average-mismatch-tm
      set sd-mismatch-tm standard-deviation [misplacement-abs] of students
      set min-score-tm min-score
      set max-rank-score-tm max-rank-score
      set mean-quartile-tm mean-quartile
      set mean-top10-tm mean-top10
      set max-top10-tm max-top10
      set percent-top10-tm percent-top10                         ;; to report misplacement-abs
    ]
    if mechanism = "Chinese parallel mechanism" [
      set average-mismatch-cp mean [misplacement-abs] of students ;show  average-mismatch-cp
      set sd-mismatch-cp standard-deviation [misplacement-abs] of students
      set min-score-cp min-score
      set max-rank-score-cp max-rank-score
      set mean-quartile-cp mean-quartile
      set mean-top10-cp mean-top10
      set max-top10-cp max-top10
      set percent-top10-cp percent-top10                         ;; to report misplacement-abs
    ]
    ;foreach sort universities [ask ? [show potential-students]]
    ;foreach sort students [ask ? [show (word score " " ten-scale-score " " three-letter-score " " choice " "  actual-place)]]
  ]

  tick
  ;;ask students [do-plots]
end

to-report cut-list [string]
  let temp (word map [(word ? ", ")] string)
  set temp remove-item 0 remove-item (length temp - 1) temp
  report temp
end

to get-score                                  ;;
  ifelse random_normal = false [
    set score random-float 100             ;; give a score between 0 - 99
  ][
    set score random-normal score-mean  score-sd
    set score ifelse-value (score > 100) [100] [score]
    set score ifelse-value (score < 0) [0] [score]
  ]
end

to get-three-latter-score
  ifelse score >= three-letter-score-t1 [set three-letter-score 6] [
    ifelse score < three-letter-score-t2 [
      set three-letter-score 2
    ] [
      set three-letter-score 4
    ]
  ]
  set ten-scale-score precision (((10 - mu) / (100 - score-mean)) * (score - score-mean) + mu) 0
  if ten-scale-score < 1 [set ten-scale-score 1]
  if ten-scale-score > 10 [set ten-scale-score 10]
end

to get-max-rank-score
  set max-rank-score map [item (? - 1) sort-by > [score] of students ] max-rank          ;; get max-rank-score based on the max-rank last year and the scores this year
end

to get-fair-place
  set u n-values num-univ [0]
  foreach sort-on  [(- score)] students [
    ask ? [
      let i 1                                 ;; the i th univ that the students choose
      while [i <= num-univ ] [
        set base-place item (i - 1) preference-list  ;;of self)
        ifelse item (base-place - 1) u >=  capacity [
          set i (i + 1)
        ] [
           set i num-univ + 2                                                             ;; to end the circle
           set u replace-item (base-place - 1) u (item (base-place - 1) u + 1)         ;; count the students
        ]
        if i = num-univ + 1 [set base-place num-univ + 1]
      ]
    ]
  ]
end

to choose                             ;; to choose university
  ifelse scheme = "1" [
    produce-random-strategy
  ] [
    produce-c&c-strategy
  ]
  ;;  move-to one-of (item (first choice - 1) univ)
end

to produce-random-strategy
  set choice n-of no-choices preference-list
  if mechanism = "Chinese parallel mechanism" [
    set choice-1 sublist choice 0 no-choices-1
    set choice-2 sublist choice no-choices-1 no-choices
  ]
end

to produce-c&c-strategy
  ifelse scheme = "2 or 3" [
    set predict-score  min-score
  ] [
    set predict-score  max-rank-score
  ]
  set choice []
  let school-left []
  let i 0
  foreach preference-list [                              ;; get the F_i set
    ifelse score >= item (? - 1) predict-score [
      set choice lput ? choice
      set i (i + 1)
    ] [
      set school-left lput ? school-left
    ]
  ]
  if i < no-choices [
    let choice_left n-of (no-choices - i) school-left
    set choice se choice choice_left
  ]

  set choice sublist choice 0 no-choices

  ifelse (mechanism = "Chinese parallel mechanism") [
    chinese-choice
  ] [
    if extra-in-order = true [
      set choice sort-by-preference choice preference-list
    ]
  ]
end

to chinese-choice
  set choice-1 sublist choice 0 no-choices-1
  set choice-2 sublist choice no-choices-1 no-choices
  if extra-in-order = true [
    set choice-1 sort-by-preference choice-1 preference-list
    set choice-2 sort-by-preference choice-2 preference-list
  ]
end

to enroll                                ;; the university give offer according to its enrollment plan and the ranking of students
  set u n-values num-univ [0]                   ;; the number of students that enrolled
  if mechanism = "Serial dictatorship"
    [serial-dictatorship]
  if mechanism = "Boston mechanism"
    [boston-mechanism]
  if mechanism = "Deferred acceptance"
    [deferred-acceptance]
  if mechanism = "Taipei mechanism"
    ;;[taipei-mechanism]
    [deferred-acceptance]
  if mechanism = "Chinese parallel mechanism"
    [chinese-parallel]
end

to serial-dictatorship
  foreach sort-on  [(- score)] students [
    ask ? [
      let i 1                                 ;; the i th univ that the students choose
      while [i <= no-choices ] [
        set actual-place (item (i - 1) [choice] of self)
        ifelse item (actual-place - 1) u >= capacity [
          set i (i + 1)                                                       ;; over capacity, not placed, test for next choice
        ] [
          set i (no-choices + 2)                                             ;; to end the circle
          ;; set utility (12 / 11 - actual-place / 11 -  score / 1089)          ;; set the utility
          ;; set misplacement abs (base-place - actual-place)                     ;; set the misplacement
          move-to one-of (item (actual-place - 1) univ)                      ;; show placement
          set color yellow                                                     ;; change display color
          set u replace-item (actual-place - 1) u (item (actual-place - 1) u + 1)         ;; count the students that enrolled
        ]
        if i = no-choices + 1 [
          ;; move-to one-of high-school set color white        ;;the student go back to high school if got no offer]
          set actual-place 11
          ;; set misplacement abs (base-place - 11)]
        ]
      ]
    ]
  ]
end

to boston-mechanism
  let n 0
  while [n < no-choices and (any? students with [color = magenta])] [
    foreach n-values 10 [?] [
      foreach sort-on [(- score)] students with  [item n choice = ? + 1 and color = magenta ] [  ; ? represents 0, 1, 2,..., 9
        ask ? [                                                                                   ;; students from highest score to lowest score
          set actual-place item n [choice] of self
          if item (actual-place - 1) u <  capacity
          [
            ;; set utility (12 / 11 - actual-place / 11 -  score / 1089)              ;; set the utility
            ;; set misplacement abs (base-place - actual-place)                        ;; set the misplacement
            move-to one-of (item (actual-place - 1) univ)
            set color yellow
            set u replace-item (actual-place - 1) u (item (actual-place - 1) u + 1)   ;; count the students that enrolled
          ]
        ]
      ]
    ]
    set n n + 1
  ]
  if any? students with  [color = magenta] [
    ask students with  [color = magenta] [
      set actual-place 11
      ;; move-to one-of high-school set color white
      ;; set misplacement abs (base-place - 11)
    ]
  ]
end

to deferred-acceptance
  let excluded-students []
  let ith_choice 0
  let ith_univ 0
  let choice-sum 1
  let temp []

  while [choice-sum != 0] [
    set ith_univ 0
    ;; create a sublist of unassigned students
    ;; initialize the list
    set excluded-students students
    foreach sort universities [
      ask ? [
        set temp students with [item next-choice choice = ([who] of ? + 1) and color = magenta ]

        let univ-priority [priority-students-list] of ?
        ;show univ-priority

        set potential-students (sort-by-preference sort temp univ-priority)
        ;show potential-students
        if length potential-students >= capacity [
          set potential-students sublist potential-students 0 capacity
        ]
        ;show potential-students

        set excluded-students (sort-by-not-listed sort excluded-students potential-students)

        foreach (sort temp) [
          if not member? ? potential-students [
            ask ? [
              set last-choice next-choice
              set next-choice next-choice + 1
              if next-choice >= (no-choices - 1) [
                set next-choice (no-choices - 1)
              ]
            ]
          ]
        ]
      ]
      set ith_univ ith_univ + 1
    ]
    ;; detect end of loop
    ;show excluded-students
    set choice-sum 0
    foreach (sort excluded-students) [
      ask ? [
        if last-choice != (no-choices - 1) [
          set choice-sum (choice-sum + 1)
        ]
      ]
    ]
    ;show choice-sum
  ]

  ; enroll
  foreach sort universities [
    ask ? [
      foreach potential-students [
        ask ? [
          set color yellow
          set actual-place ([who] of myself + 1)
          set u replace-item (actual-place - 1) u (item (actual-place - 1) u + 1)
          move-to one-of (item (actual-place - 1) univ)
        ]
      ]
    ]
  ]

  if any? students with  [color = magenta]
   [ask students with  [color = magenta]
    [
      set actual-place num-univ + 1
      ;; move-to one-of high-school set color white
       ;; set misplacement abs (base-place - 11)
    ]
  ]
end

to chinese-parallel

  foreach sort-on [(- score)] students [
    ask ? [
      let i 1                                 ;; the i th univ that the students choose
      while [i <= no-choices-1] [
        set actual-place (item (i - 1) [choice-1] of self)
        ifelse item (actual-place - 1) u >= capacity [
          set i (i + 1)                                                       ;; over capacity, not placed, test for next choice
        ] [
          set color yellow                                                    ;; change display color
          set u replace-item (actual-place - 1) u (item (actual-place - 1) u + 1)         ;; count the students that enrolled
          move-to one-of (item (actual-place - 1) univ)                       ;; show placement
          set i (no-choices-1 + 2)                                            ;; to end the circle
          ;; set utility (12 / 11 - actual-place / 11 -  score / 1089)          ;; set the utility
          ;; set misplacement abs (base-place - actual-place)                    ;; set the misplacement
        ]
        if (i = no-choices-1 + 1) and (no-choices-2 = 0) [
          ;; move-to one-of high-school set color white        ;;the student go back to high school if got no offer]
          set actual-place 11
          ;; set misplacement abs (base-place - 11)]
        ]
      ]
    ]
  ]

  if no-choices-2 != 0 [
    foreach sort-on  [(- score)] students with [color = magenta ] [
      ask ? [
        let i 1                                 ;; the i th univ that the students choose
        while [i <= no-choices-2 ] [
          set actual-place (item (i - 1) [choice-2] of self)
          ifelse item (actual-place - 1) u >=  capacity [
            set i (i + 1)
          ] [
            set i (no-choices-2 + 2)                                                    ;; to end the circle
            ;; set misplacement abs (base-place - actual-place)                         ;; set the misplacement
            move-to one-of (item (actual-place - 1) univ)
            set color yellow
            set u replace-item (actual-place - 1) u (item (actual-place - 1) u + 1)  ;; count the students that enrolled
          ]
          if i = no-choices-2 + 1 [
            ;; move-to one-of high-school set color white        ;;the student go back to high school if got no offer]
            set actual-place num-univ + 1
            ;;set misplacement abs (base-place - 11)]
          ]
        ]
      ]
    ]
  ]
end

to calculate-misplacement
  set misplacement-abs abs (base-place - actual-place)         ;; set the misplacement-abs
  set misplacement (base-place - actual-place)                 ;; set misplacement gain or loss
end

to class-mismatch
  set mean-quartile [0 0 0 0]
  ; get the 25% 50% 75% quartile using the "TI-83" method
  ; divide to students into four group according to their score
  let quartile-turtles [0 0 0 0]
 (foreach [0 1 2 3] [0 0.25 0.5 0.75] [0.25 0.5 0.75 1]
    [set quartile-turtles replace-item ?1 quartile-turtles turtle-set sublist sort-on [score] students int (?2 * num-students) int (?3 * num-students)])
  ; calculate the mean of misplacement of each quartile
  set mean-quartile replace-item 0 mean-quartile (mean [misplacement] of item 0 quartile-turtles)
  set mean-quartile replace-item 1 mean-quartile (mean [misplacement] of item 1 quartile-turtles)
  set mean-quartile replace-item 2 mean-quartile (mean [misplacement] of item 2 quartile-turtles)
  set mean-quartile replace-item 3 mean-quartile (mean [misplacement] of item 3 quartile-turtles)
  ; get the top 10% of students
  let top10 turtle-set sublist sort-on [score] students int (0.9 * num-students) num-students
  set mean-top10 mean [misplacement] of top10
  set max-top10 max [misplacement-abs] of top10
  set percent-top10 count top10 with [actual-place = base-place] / count top10
end

to update-min-score-and-rank
  let i 0
  let d (max-pxcor - min-pxcor) / num-univ
  repeat num-univ  [
    ifelse any?  students with [pycor > -10 and pxcor > (- max-pxcor + d * i) and pxcor < (- (max-pxcor - d) + d * i)] [
      set min-score replace-item i min-score ([score] of min-one-of students with [pycor > -11 and pxcor > (- max-pxcor + d * i) and pxcor < (- (max-pxcor - d) + d * i)] [score])
      set max-rank replace-item i max-rank (position (item i min-score) (sort-by > [score] of students) + 1)
    ] [
      set min-score replace-item i min-score 0
      set max-rank replace-item i max-rank num-students
    ]
    set i i + 1
  ]
end

to update-label
  let n 0
  let d (max-pxcor - min-pxcor) / num-univ
  repeat num-univ  [
    ask patch (- (max-pxcor - d / 2) + n) -11  [set plabel-color red set plabel  round item (n / d)  min-score]
    set n (n + d)
  ]
end

to-report sort-by-preference [list1 list2]        ;;define a function to sort list1 according to list2
  let newlist []
  foreach sort map [position ? list2] list1 [
    set newlist lput item ? list2 newlist
  ]
  report newlist
end

to-report sort-by-not-listed [list1 list2]        ;;define a function to sort list1 according to NOT in list2
  let newlist []
  foreach sort list1 [
    if position ? list2 = false [
      set newlist lput ? newlist
    ]
  ]
  report newlist
end

to do-plots
  set-current-plot "E1"
  set-current-plot-pen "E1"
  plotxy ticks mean [misplacement-abs] of students

  ;; set-current-plot "E2"
  ;; set-current-plot-pen "E2"
  ;; plotxy ticks mean [misplacement-abs] of students with [base-place <= 10]
  ;; set-current-plot "E3"
  ;;set-current-plot-pen "E3"
  ;;plotxy ticks mean [misplacement-abs] of students with  [color = yellow ]
end

; draw zipf (zeta) distribution

;;----------------------- generate random number in Zeta distribution (or Zipf distribution) ------------------------------------------------------
;; -----  1. Generate a uniform random number z in [0,1]
;; ------ 2. The cumulative distribution function F(x) = \frac{H_{x,a}}{H_{n,a}}, where H_{n,a} = \sum_{n=1}^{\infty}  \frac{1}{n^a}
;;------- 3. The random number we get is F^{-1}(z)
;; ---------------------------------------------------------------------------------------------------------------------------------------------------------------------
to-report zipf [n a]
  let  H 0
  let zipf-value 0

  ;draw a uniform random number z in [0,1]
  let z random-float 1
  ; calculate  H_{n,a} = \sum_{n=1}^{\infty}  \frac{1}{n^a}
  let i 1
  repeat n [
    set H (H + (1 / i) ^ a)
    set i i + 1
  ]
  ;map z to the to F^{-1}(z)
  let sum-pro 0
  set i 1
  repeat n [
    set sum-pro (sum-pro + 1 / (H * i  ^ a))
    if (sum-pro >= z) [
      set zipf-value i
      report zipf-value
      stop
    ]
    set i i + 1
  ]
end
@#$#@#$#@
GRAPHICS-WINDOW
690
10
1173
312
30
17
7.7541
1
10
1
1
1
0
1
1
1
-30
30
-17
17
1
1
1
ticks
30.0

BUTTON
60
20
187
53
setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
61
103
187
136
go
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
61
63
187
96
go once
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
205
52
377
85
num-students
num-students
0
1000
1000
1
1
NIL
HORIZONTAL

SLIDER
205
87
377
120
capacity
capacity
0
100
100
1
1
NIL
HORIZONTAL

CHOOSER
34
383
126
428
scheme
scheme
"1" "2 or 3" "4"
2

SLIDER
205
122
377
155
no-choices-1
no-choices-1
1
10
5
1
1
NIL
HORIZONTAL

PLOT
400
10
681
181
Mismatch Index
NIL
NIL
0.0
10.0
0.0
2.0
true
true
"set-plot-x-range 0 5\nset-plot-y-range 0 (max (list average-mismatch-sd average-mismatch-bm average-mismatch-da average-mismatch-tm  average-mismatch-cp) + 0.1)" "set-plot-y-range 0 ceiling (max (list average-mismatch-sd average-mismatch-bm average-mismatch-da average-mismatch-tm) + 0.1)"
PENS
"sd" 1.0 1 -13345367 true "" "plot-pen-reset\nplotxy 0 average-mismatch-sd"
"bm" 1.0 1 -7500403 true "" "plot-pen-reset\nplotxy 1 average-mismatch-bm"
"da" 1.0 1 -2674135 true "" "plot-pen-reset\nplotxy 2 average-mismatch-da"
"tm" 1.0 1 -955883 true "" "plot-pen-reset\nplotxy 3 average-mismatch-tm"
"cp" 1.0 1 -6459832 true "" "plot-pen-reset\nplotxy 4 average-mismatch-cp"

TEXTBOX
37
37
52
55
1.
12
0.0
1

TEXTBOX
36
73
51
91
2.
12
0.0
1

TEXTBOX
37
111
52
129
3.
12
0.0
1

TEXTBOX
35
305
220
335
Mechanism and Strategy
12
0.0
1

MONITOR
426
184
566
229
The Number of Enrollment
count turtles with [color = yellow]
17
1
11

MONITOR
568
184
625
229
E1
mean [misplacement-abs] of turtles
3
1
11

PLOT
337
233
678
448
Min Scores
school
Score
0.0
0.0
0.0
0.0
true
true
"set-plot-x-range 0 length min-score\nset-plot-y-range 0 100" ""
PENS
"sd" 1.0 1 -13345367 true "" "plot-pen-reset\nset min-score min-score-sd\nforeach min-score [plotxy position ? min-score ?]"
"bm" 1.0 1 -7500403 true "" "plot-pen-reset\nset min-score min-score-bm\nforeach min-score [plotxy position ? min-score ?]"
"da" 1.0 1 -2674135 true "" "plot-pen-reset\nset min-score min-score-da\nforeach min-score [plotxy position ? min-score ?]"
"tm" 1.0 1 -955883 true "" "plot-pen-reset\nset min-score min-score-tm\nforeach min-score [plotxy position ? min-score ?]"
"cp" 1.0 1 -6459832 true "" "plot-pen-reset\nset min-score min-score-cp\nforeach min-score [plotxy position ? min-score ?]"

SLIDER
35
218
193
251
population-mean
population-mean
0
100
55
1
1
NIL
HORIZONTAL

SLIDER
35
254
192
287
population-standard-deviation
population-standard-deviation
0
100
11
1
1
NIL
HORIZONTAL

SWITCH
35
182
192
215
random_normal
random_normal
0
1
-1000

CHOOSER
35
332
212
377
mechanism
mechanism
"Serial dictatorship" "Boston mechanism" "Chinese parallel mechanism" "Deferred acceptance" "Taipei mechanism"
2

SWITCH
34
437
157
470
extra-in-order
extra-in-order
1
1
-1000

SLIDER
205
157
377
190
no-choices-2
no-choices-2
0
no-choices-1
5
1
1
NIL
HORIZONTAL

TEXTBOX
50
158
200
176
Scores Generation
12
0.0
1

SWITCH
183
379
337
412
write-mismatch
write-mismatch
0
1
-1000

SWITCH
183
444
337
477
write-min-score
write-min-score
0
1
-1000

SLIDER
27
476
183
509
alpha
alpha
0
100
3
0.1
1
NIL
HORIZONTAL

PLOT
690
316
912
466
Mean of Mismath of Every Quartile
quartile
NIL
0.0
10.0
0.0
2.0
true
true
"" ""
PENS
"1st" 1.0 1 -13345367 true "" "plot-pen-reset\nplotxy 0 item 0 mean-quartile"
"2nd" 1.0 1 -7500403 true "" "plot-pen-reset\nplotxy 1 item 1 mean-quartile"
"3rd" 1.0 1 -2674135 true "" "plot-pen-reset\nplotxy 2 item 2 mean-quartile"
"4th" 1.0 1 -955883 true "" "plot-pen-reset\nplotxy 3 item 3 mean-quartile"

BUTTON
760
478
914
511
NIL
inspect one-of students
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
937
479
1108
512
NIL
inspect one-of universities
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
205
191
377
224
group-size
group-size
1
no-choices-1
2
1
1
NIL
HORIZONTAL

PLOT
917
316
1117
466
Max and mean of misplacement of Top 10 students
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot max-top10"
"pen-1" 1.0 0 -2674135 true "" "plot mean-top10"

PLOT
1121
315
1321
465
Percentage top 10% students admitted to school #1.
NIL
NIL
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot percent-top10"

SWITCH
183
476
337
509
write-mean-quartile-score
write-mean-quartile-score
0
1
-1000

SWITCH
183
411
337
444
write-sd-mismatch
write-sd-mismatch
0
1
-1000

SWITCH
213
335
336
368
All_mechanism?
All_mechanism?
0
1
-1000

SWITCH
183
509
337
542
write-mean-top10
write-mean-top10
0
1
-1000

SWITCH
337
509
491
542
write-max-top10
write-max-top10
0
1
-1000

SWITCH
492
509
654
542
write-percent-top10
write-percent-top10
0
1
-1000

SLIDER
205
19
376
52
max-tick
max-tick
0
500
30
1
1
NIL
HORIZONTAL

SWITCH
204
226
315
259
keep_files
keep_files
1
1
-1000

@#$#@#$#@
## WHAT IS IT?
we propose an agent-based model of the school admission system. We evaluate the performance of different admission systems characterized by two essential features: first, the submission deadline, either before or after the exam score is known, i.e., from dark to bright; second, the number of submittable choices, from tight to loose. We then compare the “dark-and-tight�? design with the “bright-and-loose�? design associated with appropriate behavior assumptions. When the admission is dark and tight, students’ preference revealing behavior is assumed to be truth-telling and zero-intelligent, and when the admission is bright and loose it is assumed to be truth-telling but zero-intelligent plus.

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.2.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment-chinese_4" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="50"/>
    <metric>average-mismatch</metric>
    <metric>sd-mismatch</metric>
    <enumeratedValueSet variable="random_normal">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="population-standard-deviation">
      <value value="11"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extra-in-order">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="power_function_base">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mechanism">
      <value value="&quot;Chinese parallel mechanism&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="capacity" first="20" step="30" last="50"/>
    <enumeratedValueSet variable="population-mean">
      <value value="63"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="no-choices-1">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="write-mismatch">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="no-choices-2">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="students">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="write-min-score">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="scheme">
      <value value="&quot;1&quot;"/>
      <value value="&quot;2 or 3&quot;"/>
      <value value="&quot;4&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment" repetitions="3" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <enumeratedValueSet variable="random_normal">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="write-mean-quartile-score">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="write-percent-top10">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep_files">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="write-max-top10">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="write-min-score">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extra-in-order">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="no-choices-2">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="scheme">
      <value value="&quot;1&quot;"/>
      <value value="&quot;2 or 3&quot;"/>
      <value value="&quot;4&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="no-choices-1">
      <value value="4"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="write-mismatch">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="write-mean-top10">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-students">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="population-standard-deviation">
      <value value="11"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-size">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mechanism">
      <value value="&quot;Taipei mechanism&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="write-sd-mismatch">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alpha">
      <value value="1"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="All_mechanism?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="population-mean">
      <value value="55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-tick">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capacity">
      <value value="40"/>
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100_10_nosort_3" repetitions="30" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <enumeratedValueSet variable="random_normal">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="write-mean-quartile-score">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="write-percent-top10">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep_files">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="write-max-top10">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="write-min-score">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extra-in-order">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="no-choices-2">
      <value value="3"/>
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="no-choices-1">
      <value value="2"/>
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="write-mismatch">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="write-mean-top10">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-students">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="population-standard-deviation">
      <value value="11"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-size">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mechanism">
      <value value="&quot;Taipei mechanism&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="write-sd-mismatch">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alpha">
      <value value="1"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="All_mechanism?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="population-mean">
      <value value="55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-tick">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capacity">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="scheme">
      <value value="&quot;1&quot;"/>
      <value value="&quot;2 or 3&quot;"/>
      <value value="&quot;4&quot;"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
